@@ -87,7 +87,7 @@ class Exceptions:
 
 class SSMIncidentsClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/ssm-incidents.html#SSMIncidents.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/ssm-incidents.html#SSMIncidents.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm_incidents/client.html)
     """
 
@@ -103,7 +103,7 @@ class SSMIncidentsClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/ssm-incidents.html#SSMIncidents.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/ssm-incidents.html#SSMIncidents.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm_incidents/client.html#can_paginate)
         """
 
@@ -114,7 +114,7 @@ class SSMIncidentsClient(BaseClient):
         A replication set replicates and encrypts your data to the provided Regions with
         the provided KMS key.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/ssm-incidents.html#SSMIncidents.Client.create_replication_set)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/ssm-incidents.html#SSMIncidents.Client.create_replication_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm_incidents/client.html#create_replication_set)
         """
 
@@ -133,24 +133,24 @@ class SSMIncidentsClient(BaseClient):
         """
         Creates a response plan that automates the initial response to incidents.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/ssm-incidents.html#SSMIncidents.Client.create_response_plan)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/ssm-incidents.html#SSMIncidents.Client.create_response_plan)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm_incidents/client.html#create_response_plan)
         """
 
     def create_timeline_event(
         self,
         *,
-        clientToken: str,
         eventData: str,
         eventTime: Union[datetime, str],
         eventType: str,
-        incidentRecordArn: str
+        incidentRecordArn: str,
+        clientToken: str = None
     ) -> CreateTimelineEventOutputTypeDef:
         """
         Creates a custom timeline event on the incident details page of an incident
         record.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/ssm-incidents.html#SSMIncidents.Client.create_timeline_event)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/ssm-incidents.html#SSMIncidents.Client.create_timeline_event)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm_incidents/client.html#create_timeline_event)
         """
 
@@ -158,7 +158,7 @@ class SSMIncidentsClient(BaseClient):
         """
         Delete an incident record from Incident Manager.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/ssm-incidents.html#SSMIncidents.Client.delete_incident_record)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/ssm-incidents.html#SSMIncidents.Client.delete_incident_record)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm_incidents/client.html#delete_incident_record)
         """
 
@@ -166,7 +166,7 @@ class SSMIncidentsClient(BaseClient):
         """
         Deletes all Regions in your replication set.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/ssm-incidents.html#SSMIncidents.Client.delete_replication_set)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/ssm-incidents.html#SSMIncidents.Client.delete_replication_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm_incidents/client.html#delete_replication_set)
         """
 
@@ -175,7 +175,7 @@ class SSMIncidentsClient(BaseClient):
         Deletes the resource policy that AWS Resource Access Manager uses to share your
         Incident Manager resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/ssm-incidents.html#SSMIncidents.Client.delete_resource_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/ssm-incidents.html#SSMIncidents.Client.delete_resource_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm_incidents/client.html#delete_resource_policy)
         """
 
@@ -183,7 +183,7 @@ class SSMIncidentsClient(BaseClient):
         """
         Deletes the specified response plan.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/ssm-incidents.html#SSMIncidents.Client.delete_response_plan)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/ssm-incidents.html#SSMIncidents.Client.delete_response_plan)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm_incidents/client.html#delete_response_plan)
         """
 
@@ -191,7 +191,7 @@ class SSMIncidentsClient(BaseClient):
         """
         Deletes a timeline event from an incident.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/ssm-incidents.html#SSMIncidents.Client.delete_timeline_event)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/ssm-incidents.html#SSMIncidents.Client.delete_timeline_event)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm_incidents/client.html#delete_timeline_event)
         """
 
@@ -205,7 +205,7 @@ class SSMIncidentsClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/ssm-incidents.html#SSMIncidents.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/ssm-incidents.html#SSMIncidents.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm_incidents/client.html#generate_presigned_url)
         """
 
@@ -213,7 +213,7 @@ class SSMIncidentsClient(BaseClient):
         """
         Returns the details of the specified incident record.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/ssm-incidents.html#SSMIncidents.Client.get_incident_record)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/ssm-incidents.html#SSMIncidents.Client.get_incident_record)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm_incidents/client.html#get_incident_record)
         """
 
@@ -221,7 +221,7 @@ class SSMIncidentsClient(BaseClient):
         """
         Retrieve your Incident Manager replication set.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/ssm-incidents.html#SSMIncidents.Client.get_replication_set)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/ssm-incidents.html#SSMIncidents.Client.get_replication_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm_incidents/client.html#get_replication_set)
         """
 
@@ -231,7 +231,7 @@ class SSMIncidentsClient(BaseClient):
         """
         Retrieves the resource policies attached to the specified response plan.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/ssm-incidents.html#SSMIncidents.Client.get_resource_policies)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/ssm-incidents.html#SSMIncidents.Client.get_resource_policies)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm_incidents/client.html#get_resource_policies)
         """
 
@@ -239,7 +239,7 @@ class SSMIncidentsClient(BaseClient):
         """
         Retrieves the details of the specified response plan.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/ssm-incidents.html#SSMIncidents.Client.get_response_plan)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/ssm-incidents.html#SSMIncidents.Client.get_response_plan)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm_incidents/client.html#get_response_plan)
         """
 
@@ -249,7 +249,7 @@ class SSMIncidentsClient(BaseClient):
         """
         Retrieves a timeline event based on its ID and incident record.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/ssm-incidents.html#SSMIncidents.Client.get_timeline_event)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/ssm-incidents.html#SSMIncidents.Client.get_timeline_event)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm_incidents/client.html#get_timeline_event)
         """
 
@@ -263,7 +263,7 @@ class SSMIncidentsClient(BaseClient):
         """
         Lists all incident records in your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/ssm-incidents.html#SSMIncidents.Client.list_incident_records)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/ssm-incidents.html#SSMIncidents.Client.list_incident_records)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm_incidents/client.html#list_incident_records)
         """
 
@@ -273,7 +273,7 @@ class SSMIncidentsClient(BaseClient):
         """
         List all related items for an incident record.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/ssm-incidents.html#SSMIncidents.Client.list_related_items)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/ssm-incidents.html#SSMIncidents.Client.list_related_items)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm_incidents/client.html#list_related_items)
         """
 
@@ -283,7 +283,7 @@ class SSMIncidentsClient(BaseClient):
         """
         Lists details about the replication set configured in your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/ssm-incidents.html#SSMIncidents.Client.list_replication_sets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/ssm-incidents.html#SSMIncidents.Client.list_replication_sets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm_incidents/client.html#list_replication_sets)
         """
 
@@ -293,7 +293,7 @@ class SSMIncidentsClient(BaseClient):
         """
         Lists all response plans in your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/ssm-incidents.html#SSMIncidents.Client.list_response_plans)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/ssm-incidents.html#SSMIncidents.Client.list_response_plans)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm_incidents/client.html#list_response_plans)
         """
 
@@ -301,7 +301,7 @@ class SSMIncidentsClient(BaseClient):
         """
         Lists the tags that are attached to the specified response plan.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/ssm-incidents.html#SSMIncidents.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/ssm-incidents.html#SSMIncidents.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm_incidents/client.html#list_tags_for_resource)
         """
 
@@ -318,7 +318,7 @@ class SSMIncidentsClient(BaseClient):
         """
         Lists timeline events of the specified incident record.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/ssm-incidents.html#SSMIncidents.Client.list_timeline_events)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/ssm-incidents.html#SSMIncidents.Client.list_timeline_events)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm_incidents/client.html#list_timeline_events)
         """
 
@@ -328,7 +328,7 @@ class SSMIncidentsClient(BaseClient):
         """
         Adds a resource policy to the specified response plan.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/ssm-incidents.html#SSMIncidents.Client.put_resource_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/ssm-incidents.html#SSMIncidents.Client.put_resource_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm_incidents/client.html#put_resource_policy)
         """
 
@@ -346,7 +346,7 @@ class SSMIncidentsClient(BaseClient):
         Used to start an incident from CloudWatch alarms, EventBridge events, or
         manually.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/ssm-incidents.html#SSMIncidents.Client.start_incident)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/ssm-incidents.html#SSMIncidents.Client.start_incident)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm_incidents/client.html#start_incident)
         """
 
@@ -354,7 +354,7 @@ class SSMIncidentsClient(BaseClient):
         """
         Adds a tag to a response plan.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/ssm-incidents.html#SSMIncidents.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/ssm-incidents.html#SSMIncidents.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm_incidents/client.html#tag_resource)
         """
 
@@ -362,7 +362,7 @@ class SSMIncidentsClient(BaseClient):
         """
         Removes a tag from a resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/ssm-incidents.html#SSMIncidents.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/ssm-incidents.html#SSMIncidents.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm_incidents/client.html#untag_resource)
         """
 
@@ -373,7 +373,7 @@ class SSMIncidentsClient(BaseClient):
         Update deletion protection to either allow or deny deletion of the final Region
         in a replication set.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/ssm-incidents.html#SSMIncidents.Client.update_deletion_protection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/ssm-incidents.html#SSMIncidents.Client.update_deletion_protection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm_incidents/client.html#update_deletion_protection)
         """
 
@@ -392,7 +392,7 @@ class SSMIncidentsClient(BaseClient):
         """
         Update the details of an incident record.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/ssm-incidents.html#SSMIncidents.Client.update_incident_record)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/ssm-incidents.html#SSMIncidents.Client.update_incident_record)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm_incidents/client.html#update_incident_record)
         """
 
@@ -406,7 +406,7 @@ class SSMIncidentsClient(BaseClient):
         """
         Add or remove related items from the related items tab of an incident record.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/ssm-incidents.html#SSMIncidents.Client.update_related_items)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/ssm-incidents.html#SSMIncidents.Client.update_related_items)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm_incidents/client.html#update_related_items)
         """
 
@@ -420,7 +420,7 @@ class SSMIncidentsClient(BaseClient):
         """
         Add or delete Regions from your replication set.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/ssm-incidents.html#SSMIncidents.Client.update_replication_set)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/ssm-incidents.html#SSMIncidents.Client.update_replication_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm_incidents/client.html#update_replication_set)
         """
 
@@ -442,16 +442,16 @@ class SSMIncidentsClient(BaseClient):
         """
         Updates the specified response plan.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/ssm-incidents.html#SSMIncidents.Client.update_response_plan)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/ssm-incidents.html#SSMIncidents.Client.update_response_plan)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm_incidents/client.html#update_response_plan)
         """
 
     def update_timeline_event(
         self,
         *,
-        clientToken: str,
         eventId: str,
         incidentRecordArn: str,
+        clientToken: str = None,
         eventData: str = None,
         eventTime: Union[datetime, str] = None,
         eventType: str = None
@@ -459,7 +459,7 @@ class SSMIncidentsClient(BaseClient):
         """
         Updates a timeline event.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/ssm-incidents.html#SSMIncidents.Client.update_timeline_event)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/ssm-incidents.html#SSMIncidents.Client.update_timeline_event)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm_incidents/client.html#update_timeline_event)
         """
 
@@ -468,7 +468,7 @@ class SSMIncidentsClient(BaseClient):
         self, operation_name: Literal["get_resource_policies"]
     ) -> GetResourcePoliciesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/ssm-incidents.html#SSMIncidents.Paginator.GetResourcePolicies)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/ssm-incidents.html#SSMIncidents.Paginator.GetResourcePolicies)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm_incidents/paginators.html#getresourcepoliciespaginator)
         """
 
@@ -477,7 +477,7 @@ class SSMIncidentsClient(BaseClient):
         self, operation_name: Literal["list_incident_records"]
     ) -> ListIncidentRecordsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/ssm-incidents.html#SSMIncidents.Paginator.ListIncidentRecords)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/ssm-incidents.html#SSMIncidents.Paginator.ListIncidentRecords)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm_incidents/paginators.html#listincidentrecordspaginator)
         """
 
@@ -486,7 +486,7 @@ class SSMIncidentsClient(BaseClient):
         self, operation_name: Literal["list_related_items"]
     ) -> ListRelatedItemsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/ssm-incidents.html#SSMIncidents.Paginator.ListRelatedItems)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/ssm-incidents.html#SSMIncidents.Paginator.ListRelatedItems)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm_incidents/paginators.html#listrelateditemspaginator)
         """
 
@@ -495,7 +495,7 @@ class SSMIncidentsClient(BaseClient):
         self, operation_name: Literal["list_replication_sets"]
     ) -> ListReplicationSetsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/ssm-incidents.html#SSMIncidents.Paginator.ListReplicationSets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/ssm-incidents.html#SSMIncidents.Paginator.ListReplicationSets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm_incidents/paginators.html#listreplicationsetspaginator)
         """
 
@@ -504,7 +504,7 @@ class SSMIncidentsClient(BaseClient):
         self, operation_name: Literal["list_response_plans"]
     ) -> ListResponsePlansPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/ssm-incidents.html#SSMIncidents.Paginator.ListResponsePlans)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/ssm-incidents.html#SSMIncidents.Paginator.ListResponsePlans)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm_incidents/paginators.html#listresponseplanspaginator)
         """
 
@@ -513,7 +513,7 @@ class SSMIncidentsClient(BaseClient):
         self, operation_name: Literal["list_timeline_events"]
     ) -> ListTimelineEventsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/ssm-incidents.html#SSMIncidents.Paginator.ListTimelineEvents)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/ssm-incidents.html#SSMIncidents.Paginator.ListTimelineEvents)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm_incidents/paginators.html#listtimelineeventspaginator)
         """
 
@@ -522,7 +522,7 @@ class SSMIncidentsClient(BaseClient):
         self, waiter_name: Literal["wait_for_replication_set_active"]
     ) -> WaitForReplicationSetActiveWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/ssm-incidents.html#SSMIncidents.Waiter.WaitForReplicationSetActive)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/ssm-incidents.html#SSMIncidents.Waiter.WaitForReplicationSetActive)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm_incidents/waiters.html#waitforreplicationsetactivewaiter)
         """
 
@@ -531,6 +531,6 @@ class SSMIncidentsClient(BaseClient):
         self, waiter_name: Literal["wait_for_replication_set_deleted"]
     ) -> WaitForReplicationSetDeletedWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/ssm-incidents.html#SSMIncidents.Waiter.WaitForReplicationSetDeleted)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/ssm-incidents.html#SSMIncidents.Waiter.WaitForReplicationSetDeleted)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm_incidents/waiters.html#waitforreplicationsetdeletedwaiter)
         """
